==> debug-level-0.3.2.tgz: package/lib/utils.js <==
'use strict';

/**
 * @license MIT
 * @copyright debug contributors, <commenthol@gmail.com>
 */

var LOG = 'LOG',
    DEBUG = 'DEBUG',
    INFO = 'INFO',
    WARN = 'WARN',
    ERROR = 'ERROR',
    FATAL = 'FATAL',
    OFF = 'OFF';


var LEVELS = {
  DEBUG: [FATAL, ERROR, WARN, INFO, DEBUG],
  INFO: [FATAL, ERROR, WARN, INFO],
  WARN: [FATAL, ERROR, WARN],
  ERROR: [FATAL, ERROR],
  FATAL: [FATAL],
  OFF: [OFF]
};

var COLORS = ['#0000FF', '#0033FF', '#0066FF', '#3333FF', '#3300FF', '#0000CC', '#0033CC', '#0066CC', '#3333CC', '#3300CC', '#000099', '#003399', '#333399', '#330099', '#000066', '#00FF00', '#00FF33', '#00FF66', '#00FF99', '#006633', '#00CC00', '#00CC33', '#00CC66', '#00CC99', '#006666', '#009900', '#009933', '#009966', '#009999', '#006600', '#00FFFF', '#00CCFF', '#00FFCC', '#00CCCC', '#33CCCC', '#FFFF00', '#FFFF33', '#FFCC33', '#FFCC66', '#FF9900', '#FF9933', '#FF6600', '#FF6633', '#FF0000', '#FF0033', '#FF3300', '#FF3300', '#FF3333', '#CC0000', '#CC0033', '#CC0066', '#FF0066', '#FF3366', '#FF00FF', '#FF33FF', '#CC00CC', '#990099', '#660066'];

var LEVEL_COLORS = {
  LOG: '#999999',
  DEBUG: '#0000CC',
  INFO: '#00CC00',
  WARN: '#CCCC00',
  ERROR: '#CC0000',
  FATAL: '#CC00CC'
};

var adjustLevel = function adjustLevel(level, _default) {
  level = (level || '').toUpperCase();
  return LEVELS[level] ? level : _default;
};

/**
 * @copyright debug contributors
 * @see https://github.com/visionmedia/debug
 */
var inspectOpts = function inspectOpts(obj) {
  return Object.keys(obj).filter(function (key) {
    return (/^debug_/i.test(key)
    );
  }).reduce(function (opts, key) {
    // camel-case
    var prop = key.substring(6).toLowerCase().replace(/_([a-z])/g, function (_, k) {
      return k.toUpperCase();
    });

    // coerce string value into JS value
    var val = obj[key];
    if (/^(yes|on|true|enabled)$/i.test(val)) val = true;else if (/^(no|off|false|disabled)$/i.test(val)) val = false;else if (val === 'null') val = null;else val = Number(val);

    if (prop === 'stream' || prop === 'formatters') {
      // do nothing
    } else if (prop === 'level') {
      val = adjustLevel(obj[key]);
      if (val) opts[prop] = val;
    } else if (prop === 'url') {
      opts[prop] = obj[key];
    } else {
      opts[prop] = val;
    }

    return opts;
  }, {});
};

var saveOpts = function saveOpts(obj, options) {
  Object.keys(options).forEach(function (prop) {
    if (prop === 'stream' || prop === 'formatters') return; // do not safe stream option
    var key = 'DEBUG_' + prop.replace(/([A-Z])/g, function (_, prop) {
      return '_' + prop.toLowerCase();
    });
    if (prop === 'namespaces') key = 'DEBUG';
    key = key.toUpperCase();
    obj[key] = options[prop];
  });
};

var selectColor = function selectColor(namespace, fn) {
  var hash = 0;

  for (var i in namespace) {
    hash = (hash << 5) - hash + namespace.charCodeAt(i);
    hash |= 0; // Convert to 32bit integer
  }

  var pos = Math.abs(hash) % COLORS.length;
  var color = fn(COLORS[pos]);
  return color;
};

var levelColors = function levelColors(fn) {
  var colors = Object.keys(LEVEL_COLORS).reduce(function (colors, level) {
    colors[level] = fn(LEVEL_COLORS[level]);
    return colors;
  }, {});
  return colors;
};

var inspectNamespaces = function inspectNamespaces(obj) {
  var namespaces = obj.DEBUG || obj.debug;
  if (namespaces) return { namespaces: namespaces };
};

var random = function random(len) {
  return Math.random().toString(16).toLowerCase().substr(2, len);
};

module.exports = {
  LOG: LOG,
  DEBUG: DEBUG,
  INFO: INFO,
  WARN: WARN,
  ERROR: ERROR,
  FATAL: FATAL,
  OFF: OFF,
  LEVELS: LEVELS,
  adjustLevel: adjustLevel,
  inspectOpts: inspectOpts,
  saveOpts: saveOpts,
  inspectNamespaces: inspectNamespaces,
  selectColor: selectColor,
  levelColors: levelColors,
  random: random
};

==> debug-level-1.1.0.tgz: package/lib/utils.js <==
"use strict";

/**
 * @license MIT
 * @copyright debug contributors, <commenthol@gmail.com>
 */
var LOG = 'LOG',
    DEBUG = 'DEBUG',
    INFO = 'INFO',
    WARN = 'WARN',
    ERROR = 'ERROR',
    FATAL = 'FATAL',
    OFF = 'OFF';
var LEVELS = {
  DEBUG: [FATAL, ERROR, WARN, INFO, DEBUG],
  INFO: [FATAL, ERROR, WARN, INFO],
  WARN: [FATAL, ERROR, WARN],
  ERROR: [FATAL, ERROR],
  FATAL: [FATAL],
  OFF: [OFF]
};
var COLORS = ['#6600FF', '#3333FF', '#3333CC', '#0066FF', '#0066CC', '#0066FF', '#006633', '#006666', '#006600', '#00CC00', '#00CC33', '#00CC66', '#00CC99', '#009900', '#009933', '#009966', '#009999', '#00CCFF', '#00CCCC', '#FF9900', '#FF9933', '#FF6600', '#FF6633', '#FF0000', '#FF0033', '#FF3300', '#FF3300', '#FF3333', '#CC0000', '#CC0033', '#CC0066', '#FF0066', '#FF3366', '#FF00FF', '#FF33FF', '#CC00CC', '#990099']; // // dark colors for bright background
// const COLORS_DARK = [
//   '#0000FF', '#0000CC', '#3300CC', '#000099',
//   '#003399', '#333399', '#330099', '#3300CC',
//   '#000066', '#000099', '#660066'
// ]
//
// // bright colors for dark background
// const COLORS_BRIGHT = [
//   '#00FF00', '#00FF33', '#00FF66', '#00FF99',
//   '#00FFFF', '#00FFCC',
//   '#FFFF00', '#FFFF33', '#FFCC33', '#FFCC66'
// ]

var LEVEL_COLORS = {
  LOG: '#999999',
  DEBUG: '#0066CC',
  INFO: '#009900',
  WARN: '#FF9900',
  ERROR: '#CC0000',
  FATAL: '#CC00CC'
};

var adjustLevel = function adjustLevel(level, _default) {
  level = (level || '').toUpperCase();
  return LEVELS[level] ? level : _default;
};
/**
 * @copyright debug contributors
 * @see https://github.com/visionmedia/debug
 */


var inspectOpts = function inspectOpts(obj) {
  return Object.keys(obj).filter(function (key) {
    return /^debug_/i.test(key);
  }).reduce(function (opts, key) {
    // camel-case
    var prop = key.substring(6).toLowerCase().replace(/_([a-z])/g, function (_, k) {
      return k.toUpperCase();
    }); // coerce string value into JS value

    var val = obj[key];
    if (/^(yes|on|true|enabled)$/i.test(val)) val = true;else if (/^(no|off|false|disabled)$/i.test(val)) val = false;else if (val === 'null') val = null;else val = Number(val);

    if (prop === 'stream' || prop === 'formatters') {// do nothing
    } else if (prop === 'level') {
      val = adjustLevel(obj[key]);
      if (val) opts[prop] = val;
    } else if (prop === 'url') {
      opts[prop] = obj[key];
    } else {
      opts[prop] = val;
    }

    return opts;
  }, {});
};

var saveOpts = function saveOpts(obj, options) {
  Object.keys(options).forEach(function (prop) {
    if (prop === 'stream' || prop === 'formatters') return; // do not safe stream option

    var key = 'DEBUG_' + prop.replace(/([A-Z])/g, function (_, prop) {
      return '_' + prop.toLowerCase();
    });
    if (prop === 'namespaces') key = 'DEBUG';
    key = key.toUpperCase();
    obj[key] = options[prop];
  });
};

var selectColor = function selectColor(namespace, fn) {
  var hash = 0;

  for (var i in namespace) {
    hash = (hash << 5) - hash + namespace.charCodeAt(i);
    hash |= 0; // Convert to 32bit integer
  }

  var pos = Math.abs(hash) % COLORS.length;
  var color = fn(COLORS[pos]);
  return color;
};

var levelColors = function levelColors(fn) {
  var colors = Object.keys(LEVEL_COLORS).reduce(function (colors, level) {
    colors[level] = fn(LEVEL_COLORS[level]);
    return colors;
  }, {});
  return colors;
};

var inspectNamespaces = function inspectNamespaces(obj) {
  var namespaces = obj.DEBUG || obj.debug;
  if (namespaces) return {
    namespaces: namespaces
  };
};

var random = function random(len) {
  return Math.random().toString(16).toLowerCase().substr(2, len);
};

module.exports = {
  LOG: LOG,
  DEBUG: DEBUG,
  INFO: INFO,
  WARN: WARN,
  ERROR: ERROR,
  FATAL: FATAL,
  OFF: OFF,
  LEVELS: LEVELS,
  COLORS: COLORS,
  LEVEL_COLORS: LEVEL_COLORS,
  adjustLevel: adjustLevel,
  inspectOpts: inspectOpts,
  saveOpts: saveOpts,
  inspectNamespaces: inspectNamespaces,
  selectColor: selectColor,
  levelColors: levelColors,
  random: random
};
